Added Nambu spin configuration

Allowed `sisl` to operate with the Nambu spin-configuration.
This spin-configuration is made for spin-orbit +
super-conductivity.

Nearly all functionality that is available for SOC is also
availiable for BdG (Nambu) spin configuration.

This goes in line with the recent additions to the Siesta
code with superconductivity.
